@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.3.2 date 2007-07-18
- * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3 date 2006-12-18
+ * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -158,7 +158,7 @@ void bd_config_get( char * filename )
 
   //parse base brighness value
   if( sscanf( bd_map_base_str, "%lf", &bd_map_base ) != 1 ||
-      bd_map_base < 0.0 || bd_map_base > 1.0 )
+      bd_map_base <= 0.0 || bd_map_base > 1.0 )
   {
     printf( "config: mapping: error in format of base brightness value (\"%s\"), using 0.0\n", bd_map_base_str );
     bd_map_base = 0.0;
@@ -325,7 +325,7 @@ void bd_config_get( char * filename )
     printf( "config: output: error in format of suffix count (\"%s\"), using 1\n", bd_out_suffix_cnt_str );
     bd_out_suffix_cnt = 1;
   }
-  if( bd_out_suffix_cnt > 16 )
+  if( bd_out_suffix > 16 )
   {
     printf( "config: output: invalid suffix count (%d), using 1\n", bd_out_suffix_cnt );
     bd_out_suffix_cnt = 1;
