@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.3.2 date 2007-07-18
- * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3 date 2006-12-18
+ * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -58,8 +58,7 @@ int main( int arg_cnt, char * * args )
   unsigned int last_recv, cur;
   struct timeval timeout;
   unsigned short dev_no, ser_no, pix_no, suffix_no;
-  int cnt, len, i, y, x;
-  unsigned int addr_len;
+  int cnt, len, addr_len, i, y, x;
   unsigned char * ptr;
   in_addr_t in_addr;
   int timeout_detected;
@@ -67,8 +66,8 @@ int main( int arg_cnt, char * * args )
   //print message
   printf( "\n"
           "bluebox distributor\n"
-          "version 0.3.2 date 2007-07-18\n"
-          "Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>\n"
+          "version 0.3 date 2006-12-18\n"
+          "Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>\n"
           "Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html\n"
           "a BlinkenArea project - http://www.blinkenarea.org/\n"
           "\n" );
@@ -330,14 +329,13 @@ int main( int arg_cnt, char * * args )
   while( ! end )
   {
     cur = get_ms( );
-    unsigned int wait_time = cur - last_recv;
 
     //detect timeout
-    if( wait_time >= bd_in_timeout * 1000 )
+    if( cur - last_recv >= bd_in_timeout * 1000 )
       timeout_detected = 1;
     
     //detect elapsed timeout interval
-    if( timeout_detected && wait_time >= bd_in_timeout_interval * 1000 ) {
+    if( timeout_detected && cur - last_recv >= bd_in_timeout_interval * 1000 ) {
       //remember this time as time of last reception
       last_recv = cur;
       //send turn off commands using output socket
@@ -371,20 +369,17 @@ int main( int arg_cnt, char * * args )
         //calculate IP address of next device
         in_addr += bd_out_ip_step;
       } //for( dev_no ...
-    } //if( timeout_detected && wait_time >= bd_in_timeout_interval * 1000 )
+    } //if( timeout_detected && cur - last_recv >= bd_in_timeout_interval * 1000 )
 
     //wait for reception of a datagram
     FD_ZERO( &fdset );
     FD_SET( in_sock_fd, &fdset );
     timeout.tv_sec = 0;
-    unsigned int wait_time_x = cur - last_recv;
-    if( wait_time_x >= bd_in_timeout * 1000 || (timeout_detected && wait_time_x >= bd_in_timeout_interval * 1000) )
+    if( cur - last_recv >= bd_in_timeout * 1000 )
       timeout.tv_usec = 0;
     else
     {
-      unsigned int timeout_ms_to = bd_in_timeout * 1000 - wait_time_x;
-      unsigned int timeout_ms_to_i = bd_in_timeout_interval * 1000 - wait_time_x;
-      unsigned int timeout_ms = timeout_ms_to < timeout_ms_to_i ? timeout_ms_to : timeout_ms_to_i;
+      unsigned int timeout_ms = bd_in_timeout * 1000 - (cur - last_recv);
       timeout.tv_usec = timeout_ms < 100 ? timeout_ms * 1000 : 100000;
     }
     cnt = select( in_sock_fd + 1, &fdset, NULL, NULL, &timeout );
