@@ -1,6 +1,6 @@
 /* bluebox distributor
- * version 0.3.2 date 2007-07-18
- * Copyright (C) 2006-2007 Stefan Schuermans <1stein@blinkenarea.org>
+ * version 0.3 date 2006-12-18
+ * Copyright (C) 2006 Stefan Schuermans <1stein@blinkenarea.org>
  * Copyleft: GNU public license V2.0 - http://www.gnu.org/copyleft/gpl.html
  * a BlinkenArea project - http://www.blinkenarea.org/
  */
@@ -50,7 +50,7 @@ int proto_datagram( unsigned char * p_datagram, unsigned int datagram_len,
   unsigned char value;
 
   //parse frame in datagram
-  p_frame = BlinkenFrameFromNetwork( (char *)p_datagram, datagram_len, &proto );
+  p_frame = BlinkenFrameFromNetwork( p_datagram, datagram_len, &proto );
   if( p_frame == NULL )
     return 0;
 
